==> blobAndConquer-0.1-1.tar.gz: BlobAndConquer/src/combat.cpp <==
/*
Copyright (C) 2005 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "combat.h"

void attackTarget(Unit *unit)
{
	if (unit->reload > 0)
	{
		return;
	}

	fireWeapon(unit, unit->currentWeapon, unit->position, unit->target->position);
}

// fires less accurately so the shots scatter around a dodging target
void attackTargetScatter(Unit *unit)
{
	static int scatterAdjustment;
	
	if (unit->reload > 0)
	{
		return;
	}

	Vector targetPosition = unit->target->position;
	
	scatterAdjustment = 2;
	scatterAdjustment += (int)(Math::getDistance(unit->position.x, unit->position.y, targetPosition.x, targetPosition.y) / 15);

	targetPosition.x += Math::rrand(-scatterAdjustment, scatterAdjustment);
	targetPosition.y += Math::rrand(-scatterAdjustment, scatterAdjustment);

	fireWeapon(unit, unit->currentWeapon, unit->position, targetPosition);
}

// Calculates where the unit will be at X time and fires at that position
void attackTargetLeading(Unit *unit)
{
}

==> blobAndConquer-0.3-1.tar.gz: BlobAndConquer/src/combat.cpp <==
/*
Copyright (C) 2006 Parallel Realities

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

*/

#include "combat.h"

Vector getLeadingTargetPosition(Entity *attacker, Entity *target)
{
	float distance = Math::getDistance(attacker->position, target->position);
			
	Vector targetSpeed = (target->velocity * (distance / BULLET_MOVE_SPEED));
			
	Vector targetPosition = target->position;
	targetPosition += targetSpeed;
	
	return targetPosition;
}

void attackTarget(Unit *unit)
{
	if (unit->reload > 0)
	{
		return;
	}
	
	fireWeapon(unit, unit->currentWeapon, unit->position, unit->target->position);
}

// Calculates where the unit will be at X time and fires at that position
void attackTargetLeading(Unit *unit)
{
	if (unit->reload > 0)
	{
		return;
	}
	
	Vector target = getLeadingTargetPosition(unit, unit->target);
	
	fireWeapon(unit, unit->currentWeapon, unit->position, target);
}
